// xmpp-client: A sample GTK client in Rust
// Copyright (C) 2024 Link Mauve <linkmauve@linkmauve.fr>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

use adw::prelude::*;
use adw::subclass::prelude::*;
use gtk::glib;

mod imp {
    use adw::subclass::prelude::*;
    use gtk::glib;

    /// The private struct, which can hold widgets and other data.
    #[derive(Debug, Default, gtk::CompositeTemplate)]
    #[template(file = "chat_tab.ui")]
    pub struct ChatTab {
        #[template_child]
        pub avatar: TemplateChild<gtk::Image>,
        #[template_child]
        pub name: TemplateChild<gtk::Label>,
    }

    #[glib::object_subclass]
    impl ObjectSubclass for ChatTab {
        const NAME: &'static str = "ChatTab";
        type Type = super::ChatTab;
        type ParentType = gtk::Box;

        fn class_init(class: &mut Self::Class) {
            class.bind_template();
        }

        fn instance_init(obj: &glib::subclass::InitializingObject<Self>) {
            obj.init_template();
        }
    }

    impl ObjectImpl for ChatTab {
        fn constructed(&self) {
            self.parent_constructed();
        }
    }

    impl WidgetImpl for ChatTab {}
    impl BoxImpl for ChatTab {}
}

glib::wrapper! {
    pub struct ChatTab(ObjectSubclass<imp::ChatTab>)
        @extends gtk::Widget, gtk::Box;
}

impl ChatTab {
    pub fn new() -> Self {
        glib::Object::builder().build()
    }

    pub fn set_jid(&self, jid: &str) {
        self.set_tooltip_text(Some(jid));
    }

    pub fn set_avatar_hash(&self, hash: &str) {
        // let xdg_cache = std::env::var("XDG_CACHE_HOME").unwrap_or(format!(
        //     "{}/.cache",
        //     std::env::var("HOME").expect("NO $HOME?!")
        // ));
        // let xdg_cache = PathBuf::from(xdg_cache);
        // let entry = xdg_cache.join("poezio/avatars").join(self.tooltip_text().unwrap()).join(hash);

        // self.imp().avatar.set_from_file(Some(entry.to_str().unwrap().to_string()));
        self.imp().avatar.set_from_file(Some(hash));
    }

    pub fn set_name(&self, name: &str) {
        self.imp().name.set_label(name);
    }
}
